@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-"""UPnP client module."""
+"""async_upnp_client.client module."""
 
 import logging
 import urllib.parse
@@ -651,7 +651,6 @@ class UpnpAction:
             "SOAPAction": f'"{soap_action}"',
             "Host": urllib.parse.urlparse(control_url).netloc,
             "Content-Type": 'text/xml; charset="utf-8"',
-            "Content-Length": str(len(body)),
         }
 
         return control_url, headers, body
