@@ -1,9 +1,12 @@
-"""Device update listener."""
+# -*- coding: utf-8 -*-
+"""async_upnp_client.device_updater module."""
 
 import logging
 from typing import Optional
 
-from async_upnp_client import SsdpAdvertisementListener, UpnpDevice, UpnpFactory
+from async_upnp_client.advertisement import SsdpAdvertisementListener
+from async_upnp_client.client import UpnpDevice
+from async_upnp_client.client_factory import UpnpFactory
 from async_upnp_client.const import AddressTupleVXType, SsdpHeaders
 
 _LOGGER = logging.getLogger(__name__)
